@@ -3,5 +3,6 @@ __all__ = ['topic', 'trace_elimination', 'music_score_recognition', 'speech_reco
            'skin_recognition', 'watermark_removal', 'ocr_rec', 'paper_rotation', 'speech_synthesis', 'topic_loc',
            'teacher_qualification_check', 'object_detection', 'image_search', 'cutout_and_beauty',
            'idphoto_deep_beauty_to_b', 'gpu_accelerate', 'original_background_crop', 'title_detector', 'skin_quality',
-           'wedding_photo_classic', 'image_handle_classic', 'face_info_classic', 'doc_correct', 'watermark_removal_video',
-           'silent_reading_context_detect']
+           'wedding_photo_classic', 'image_handle_classic', 'face_info_classic', 'doc_correct',
+           'watermark_removal_video', 'silent_reading_context_detect', 'check_photo_classic',
+           'double_picture_stitching', 'single_human_editor']
